package com.agfa.oss.wildfly.it.timers;

import javax.annotation.PostConstruct;
import javax.annotation.Resource;
import javax.ejb.ConcurrencyManagement;
import javax.ejb.ConcurrencyManagementType;
import javax.ejb.Lock;
import javax.ejb.LockType;
import javax.ejb.ScheduleExpression;
import javax.ejb.Singleton;
import javax.ejb.Startup;
import javax.ejb.Timeout;
import javax.ejb.Timer;
import javax.ejb.TimerConfig;
import javax.ejb.TimerService;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@Singleton
@Startup
@ConcurrencyManagement(ConcurrencyManagementType.BEAN)
public class TimersStartup {
	private static final Logger LOG = LoggerFactory.getLogger(TimersStartup.class);
	private static final String TIMER_NAME = TimersStartup.class.getName() + "-T1";
	
	@Resource TimerService ts;
	
	@Timeout
	@Lock(LockType.READ)
	public void timeout(Timer t) {
		LOG.info("executing timer {}", t);
	}

	@PostConstruct
	public void init() {
		// Let's create a persistent timer configuration 
		TimerConfig ourTimerConfiguration = new TimerConfig(TIMER_NAME, true);
		
		// That will execute every hour
		ScheduleExpression everyHourFromNowExpression = new ScheduleExpression().hour("*");
		
		Timer t = ts.createCalendarTimer(everyHourFromNowExpression, ourTimerConfiguration);
		t.cancel();
	} 
}
